####################################################################################################
#  This file contains the correspondency between the leagues of sport_API and PS3838               #
#  For each country, the correspondency is a dictionary with the following structure:              #
#       ('name_league_sport_api', id_league_sport_api) : ('name_league_ps3838', id_league_PS3838)  #
####################################################################################################
CORRESPONDENCY_DICT_LEAGUES = {
"World" : 
{
('Euro Championship', 4) : ('EURO', 5264),
('Confederations Cup', 21) : ('Confederation Cup Corners', 199461),
('World Cup', 1) : ('World Cup', 2686),
('Asian Games', 803) : None,
('Caribbean Cup', 804) : ('Caribbean Cup', 204985),
('UEFA Champions League', 2) : ('Champions League', 2627),
('Asian Cup', 7) : ('Asian Cup', 1707),
('World Cup - Women', 8) : ('World Cup Women', 2687),
('FIFA Club World Cup', 15) : ('Club World Cup', 1865),
('Olympics Men', 480) : ('Men U23', 197231),
('CECAFA Senior Challenge Cup', 535) : ('Club Cup', 201947),
('SAFF Championship', 28) : ('Seniors Championship', 225488),
('UEFA Europa League', 3) : ('Europa League', 2630),
('AFC Challenge Cup', 807) : ('Cup', 1709),
('African Nations Championship', 19) : ('African Nations Championship Corners', 192619),
('AFF Championship', 24) : ('Championship', 1744),
('World Cup - Qualification Intercontinental Play-offs', 37) : ('World Cup Qualifiers Intercontinental', 219415),
('CONCACAF Gold Cup', 22) : ('Gold Cup Corners', 6401),
('EAFF E-1 Football Championship', 23) : ('E-1 Championship Women', 6435),
('OFC Champions League', 27) : ('Champions League', 125458),
('Africa Cup of Nations', 6) : ('Cup of Nations', 218006),
('Copa America', 9) : ('Copa America', 1872),
('Olympics Women', 524) : ('Women', 5000),
('UEFA Super Cup', 531) : ('Super Cup', 2636),
('CONCACAF Champions League', 16) : ('Champions League', 1715),
('AFC Champions League', 17) : ('Champions League', 1708),
('Gulf Cup of Nations', 25) : ('Arabian Gulf Cup', 2090),
('International Champions Cup', 26) : ('Cup of Champions', 219187),
('Copa Centroamericana', 805) : ('Central American Cup', 227146),
('OFC Nations Cup', 806) : None,
('China Cup', 766) : None,
('Friendlies', 10) : ('Friendlies', 2117),
('UEFA Youth League', 14) : ('Youth League U19', 6619),
('AFC Cup', 18) : ('Cup', 1709),
('CAF Confederation Cup', 20) : ('Confederation Cup', 187709),
('UEFA U21 Championship', 38) : ('U21 European Championship', 2639),
('World Cup - U20', 490) : ('World Cup U20', 2620),
('UEFA Nations League', 5) : ('Nations League A', 200719),
('CONCACAF Nations League - Qualification', 808) : ('Nations League - Qualifiers', 202502),
('World Cup - Qualification CONCACAF', 31) : ('World Cup Qualifiers CONCACAF', 212593),
('World Cup - Qualification Europe', 32) : ('World Cup Qualifiers Europe', 2015),
('World Cup - Qualification Oceania', 33) : ('World Cup Qualifiers Oceania', 5001),
('World Cup - Qualification South America', 34) : ('World Cup Qualifiers South America', 2016),
('World Cup - Qualification Africa', 29) : ('World Cup Qualifiers Africa', 2013),
('World Cup - Qualification Asia', 30) : ('World Cup Qualifiers Asia', 2014),
('UEFA U19 Championship', 493) : ('U19 European Championship', 2638),
('CONCACAF U20', 537) : ('U20 Championship', 4787),
('UEFA Champions League Women', 525) : ('Champions League Women', 2642),
('CAF Super Cup', 533) : ('Super Cup', 208188),
('CONCACAF Caribbean Club Shield', 534) : ('Caribbean Club Shield', 227282),
('CONMEBOL Sudamericana', 11) : ('Copa Sudamericana', 2472),
('CAF Champions League', 12) : ('Champions League', 1715),
('CONMEBOL Libertadores', 13) : ('Copa Libertadores', 1875),
('Asian Cup - Qualification', 35) : ('Asian Cup Qualifiers', 198935),
('Arab Club Champions Cup', 768) : ('Arab Club Champions Cup', 199525),
('Premier League Asia Trophy', 769) : ('Premier League Asia Trophy', 205800),
('Pacific Games', 770) : None,
('Leagues Cup', 772) : ('Leagues Cup', 205939),
('Sudamericano U20', 773) : None,
('World Cup - U17', 587) : ('World Cup U17', 2608),
('CONCACAF League', 767) : ('League', 199581),
('COSAFA U20 Championship', 771) : ('U20 Championship', 203600),
('Baltic Cup', 849) : ('Baltic Cup', 1801),
('AFC U23 Asian Cup', 532) : ('U23 Cup', 35179),
('CONCACAF Nations League', 536) : ('Nations League', 206571),
('Africa Cup of Nations U20', 538) : ('Cup of Nations U20', 226786),
('CONMEBOL Libertadores U20', 540) : ('Copa Libertadores U20', 192708),
('CONMEBOL Recopa', 541) : ('Recopa Sudamericana', 2394),
('Olympics Men - Qualification Concacaf', 881) : ('Olympic Qualifiers', 212499),
('Olympics Women - Qualification Asia', 882) : None,
('Campeones Cup', 885) : ('Campeones Cup', 227961),
('Friendlies Women', 666) : ('Friendlies Women', 2116),
('Friendlies Clubs', 667) : ('Club Friendlies', 1863),
('UEFA Championship - Women', 743) : None,
('UEFA Europa Conference League', 848) : ('Europa Conference League', 214101),
('CONCACAF Caribbean Club Championship', 856) : None,
('CONCACAF Gold Cup - Qualification', 858) : ('Gold Cup Qualifiers', 35185),
('COSAFA Cup', 859) : ('Cup', 197076),
('Arab Cup', 860) : ('Arab Cup', 213780),
('Youth Viareggio Cup', 910) : ('Viareggio Cup U19', 204442),
('CECAFA Club Cup', 869) : ('Club Cup', 201947),
('World Cup - Women - Qualification Europe', 880) : ('World Cup Women Qualifiers Europe', 198974),
('U20 Elite League', 890) : None,
('Algarve Cup', 902) : ('Algarve Cup Women', 7953),
('The Atlantic Cup', 903) : None,
('Africa Cup of Nations - Qualification', 36) : ('Africa Cup of Nations Qualifiers', 1713),
('International Champions Cup - Women', 945) : ('Champions Cup Women', 206309),
('CONMEBOL Libertadores Femenina', 949) : ('Copa Libertadores Femenina', 198147),
('World Cup - U17 - Women', 950) : ('World Cup U17 Women', 4483),
('South American Youth Games', 951) : ('South American Youth Games U20', 201677),
('AFC U23 Asian Cup - Qualification', 952) : ('U23 Asian Cup Qualification', 216769),
('Africa U23 Cup of Nations - Qualification', 953) : ('Africa Cup of Nations U23 Corners', 204534),
('Southeast Asian Games', 911) : ('SEA Games - Mens', 185680),
('CONCACAF Women U17', 912) : None,
('CONMEBOL - UEFA Finalissima', 913) : None,
('Tournoi Maurice Revello', 914) : ('Maurice Revello Youth Tournament', 2562),
('Kirin Cup', 916) : ('Kirin Cup', 2179),
('UEFA U19 Championship - Women', 918) : ('U19 Euro Championship Women', 187792),
('Mediterranean Games', 919) : ('Mediterranean Games', 201922),
('World Cup - U20 - Women', 920) : ('World Cup U20 Women', 2010),
('UEFA U17 Championship', 921) : ('U17 Euro Championship', 2637),
('Africa Cup of Nations - Women', 922) : ('Africa Women Cup of Nations', 198017),
('Copa America Femenina', 926) : ('Copa America Femenina', 201194),
('World Cup - Women - Qualification Concacaf', 927) : None,
('AFF U19 Championship', 928) : ('U19 Championship',  197640),
('Arab Championship - U20', 934) : None,
('Emirates Cup', 937) : ('Emirates Cup', 1950),
('COTIF Tournament', 940) : None,
('Islamic Solidarity Games', 941) : ('Islamic Solidarity Games U23', 221392),
('CAC Games', 1016) : None,
('UEFA U17 Championship - Qualification', 886) : ('U17 Championship Qualifiers', 200033),
('UEFA U19 Championship - Qualification', 893) : ('U19 Euro Championship Qualifiers', 5983),
('Asian Cup Women - Qualification', 894) : ('Asian Cup Women Qualifiers', 215865),
('Asian Cup Women', 897) : ('Asian Cup Women', 8562),
('Tipsport Malta Cup', 900) : None,
('SheBelieves Cup', 904) : ('SheBelieves Cup Women', 204340),
('AFF U23 Championship', 908) : ('U23 Championship', 218623),
('UEFA U21 Championship - Qualification', 850) : ('U21 Euro Championship Qualifiers', 5982),
('African Football League', 1043) : ('African Football League', 230376),
('Pan American Games', 1045) : None,
('All Africa Games', 1072) : None,
('Euro Championship - Qualification', 960) : None,
('CONCACAF U17', 963) : None,
('AFC U20 Asian Cup', 965) : ('U20 Cup', 224527),
('CONMEBOL - U17', 970) : None,
('CAF Cup of Nations - U17', 973) : ('Cup of Nations U20', 226786),
('CAFA Nations Cup', 1008) : None,
('AFC U17 Asian Cup', 1012) : ('U17 Cup', 226452),
('All-Island Cup - Women', 1013) : None,
('CAF U23 Cup of Nations', 1015) : ('Africa Cup of Nations U23', 192351),
('UEFA - CONMEBOL - Club Challenge', 1024) : ('Club Challenge', 226909),
('Concacaf Central American Cup', 1028) : ('Central American Cup', 227146),
("King's Cup", 1038) : ('Kings Cup', 2178),
('Premier League International Cup', 1039) : None,
('UEFA Nations League - Women', 1040) : ('Nations League Women', 227902),
('CONCACAF Women U20', 1001) : ('U20 Championship Women', 199440),
('CONCACAF Gold Cup - Qualification - Women', 1046) : ('Gold Cup Qualifiers Women', 227942),
('Olympics Women - Qualification CAF', 1047) : ('Olympic Qualifiers Women', 226857),
('CONCACAF Gold Cup - Women', 1057) : ('Gold Cup Women', 234262),
('CONMEBOL - Pre-Olympic Tournament', 1060) : ('Pre-Olympic Tournament U23', 207687),
('CONCACAF U20 - Qualification', 1066) : ('U20 Championship Qualifiers', 234264),
('AFC U20 Asian Cup - Women', 1070) : ('U20 Cup Women', 207121),
('WAFF Championship U23', 1077) : ('Championship U23',  216345),
('CONMEBOL - U17 Femenino', 1081) : ('U17 Championship Women', 218795),
('CONMEBOL U20 Femenino', 1085) : ('U20 Championship Women', 2473),
('UAE-Qatar - Super Shield', 1089) : None,
('AFC U17 Asian Cup - Women', 1101) : None,
('UEFA U17 Championship - Women', 1102) : ('U17 Championship Women', 206948),
('Olympics - Intercontinental Play-offs', 1105) : None,
('OFC U19 Championship', 1122) : None,
('Qatar-UAE Super Cup', 1123) : ('Super Cup', 234970),
('UEFA Championship - Women - Qualification', 1083) : None,
},
"France" : 
{
('Ligue 1', 61) : ('Ligue 1', 2036),
('Ligue 2', 62) : ('Ligue 2', 2037),
('National 1', 63) : ('National', 2027),
('Coupe de France', 66) : ('Cup', 2032),
('Coupe de la Ligue', 65) : ('League Cup', 2034),
('National 2 - Group A', 67) : ('National 2', 200815),
('National 2 - Group B', 68) : ('National 2', 200815),
('National 2 - Group C', 69) : ('National 2', 200815),
('National 2 - Group D', 70) : ('National 2', 200815),
('Trophée des Champions', 526) : ('Super Cup', 2035),
('Feminine Division 1', 64) : ('Feminine Division 1', 2033),
('National 3 - Group A', 461) : ('National 3', 215521),
('National 3 - Group B', 462) : ('National 3', 215521),
('National 3 - Group C', 463) : ('National 3', 215521),
('National 3 - Group D', 464) : ('National 3', 215521),
('National 3 - Group E', 465) : ('National 3', 215521),
('National 3 - Group F', 466) : ('National 3', 215521),
('National 3 - Group H', 467) : ('National 3', 215521),
('National 3 - Group I', 468) : ('National 3', 215521),
('National 3 - Group J', 469) : ('National 3', 215521),
('National 3 - Group K', 470) : ('National 3', 215521),
('National 3 - Group L', 471) : ('National 3', 215521),
('National 3 - Group M', 472) : ('National 3', 215521),
('National 3 - Group G', 1029) : ('National 3', 215521),
},
"Belgium" : 
{
('Jupiler Pro League', 144) : ('Pro League', 1817),
('Super Cup', 519) : ('Super Cup', 1816),
('Challenger Pro League', 145) : ('Challenger Pro League', 1818),
('Super League Women', 146) : ('Super League Women', 196778),
('Second Amateur Division - VFV A', 149) : ('2nd Amateur Division', 218689),
('Second Amateur Division - VFV B', 150) : ('2nd Amateur Division', 218689),
('Third Amateur Division - VFV A', 151) : None,
('Third Amateur Division - VFV B', 152) : None,
('Second Amateur Division - ACFF', 148) : ('2nd Amateur Division', 218689),
('Provincial - Antwerpen', 153) : None,
('Provincial - Brabant VFV', 154) : None,
('Provincial - Hainaut', 155) : None,
('Provincial - Liege', 156) : None,
('Provincial - Limburg', 157) : None,
('Provincial - Luxembourg', 158) : None,
('Provincial - Namur', 159) : None,
('Provincial - Oost-Vlaanderen', 160) : None,
('Provincial - West-Vlaanderen', 161) : None,
('First Amateur Division', 487) : ('First Amateur Division', 202447),
('Reserve Pro League', 518) : ('Reserve Pro League U21', 209638),
('Cup', 147) : ('Cup', 1819),
('Third Amateur Division - ACFF A', 689) : ('First Amateur Division', 202447),
('Third Amateur Division - ACFF B', 690) : ('First Amateur Division', 202447),
('Provincial - Brabant ACFF', 691) : None,
('Provincial - Play-offs VV', 979) : None,
('Provincial - Play-offs ACFF', 980) : None,
('Third Amateur Division - Play-offs', 981) : ('First Amateur Division', 202447),
('Second Amateur Division - Play-offs ', 1011) : ('2nd Amateur Division', 218689),
},
"Brazil" : 
{
('Serie A', 71) : ('Serie A', 1834),
('Serie C', 75) : ('Serie C', 1836),
('Serie D', 76) : ('Serie D', 201371),
('Serie B', 72) : ('Serie B', 1835),
('Acreano', 520) : None,
('Amapaense', 521) : ('Amapaense', 219613),
('Amazonense', 522) : ('Amazonense', 218399),
('Copa Do Brasil', 73) : ('Cup', 1833),
('Brasileiro Women', 74) : ('Brasileiro Women', 201364),
('Alagoano', 77) : ('Alagoano', 192685),
('Baiano - 2', 613) : ('Baiano 2', 214197),
('Cearense - 2', 620) : ('Cearense 2', 211046),
('Carioca - 2', 625) : ('Carioca 2', 194726),
('Baiano - 1', 602) : ('Baiano', 10769),
('Paraibano', 603) : ('Paraibano', 192778),
('Catarinense - 1', 604) : ('Catarinense', 10776),
('Paulista - A3', 605) : ('Paulista A3', 203914),
('Paranaense - 1', 606) : ('Paranaense', 10770),
('Roraimense', 607) : ('Roraimense', 218917),
('Maranhense', 608) : ('Maranhense 1', 192701),
('Cearense - 1', 609) : ('Cearense', 10768),
('Brasiliense', 610) : ('Brasiliense', 192841),
('Capixaba', 611) : ('Capixaba', 218547),
('Copa do Nordeste', 612) : ('Copa Do Nordeste', 10883),
('Paranaense - 2', 614) : ('Paranaense 2', 198925),
('Rondoniense', 615) : ('Rondoniense', 218691),
('Potiguar', 616) : ('Potiguar', 11681),
('Copa do Brasil U20', 617) : ('Copa Goias U20', 222593),
('São Paulo Youth Cup', 618) : ('Sao Paulo Cup U20', 218024),
('Mineiro - 2', 619) : ('Mineiro 2', 204522),
('Piauiense', 621) : ('Piauiense', 203930),
('Pernambucano - 1', 622) : ('Pernambucano', 10885),
('Sul-Matogrossense', 623) : ('Sul-Matogrossense', 218519),
('Carioca - 1', 624) : ('Carioca B1', 216958),
('Sergipano', 626) : ('Sergipano', 196773),
('Paraense', 627) : ('Paraense', 198451),
('Goiano - 1', 628) : ('Goiano', 10780),
('Mineiro - 1', 629) : ('Mineiro', 10778),
('Matogrossense', 630) : ('Mato-Grossense', 200573),
('Tocantinense', 631) : ('Tocantinense', 217845),
('Supercopa do Brasil', 632) : ('Supercopa Corners', 224043),
('Copa Verde', 843) : ('Copa Verde', 75455),
('Paulista - A1', 475) : None,
('Paulista - A2', 476) : ('Paulista A2', 10782),
('Gaúcho - 1', 477) : ('Gaucho', 1829),
('Gaúcho - 2', 478) : ('Gaucho 2', 201007),
('CBF Brasileiro U20', 740) : ('Brasileiro U20', 210902),
('Brasileiro de Aspirantes', 741) : None,
('Copa Paulista', 742) : ('Copa Paulista', 191548),
('Carioca A2', 851) : ('Carioca A2', 215951),
('Catarinense - 2', 936) : ('Catarinense 2', 201811),
('Goiano - 2', 1030) : ('Goiano 2', 206585),
('Copa Rio', 1035) : ('Copa Rio U20', 216059),
('Copa Santa Catarina', 1036) : ('Copa Santa Catarina', 202622),
('Paraibano 2', 1037) : ('Paraibano 2', 216937),
('Recopa Catarinense', 1059) : ('Recopa Catarinense', 233899),
('Paulista - A4', 1062) : ('Paulista A4', 201334),
('Copa Alagoas', 1063) : ('Copa Alagoas', 211794),
('Goiano U20', 1069) : ('Goiano U20', 216061),
('Paranaense U20', 1071) : ('Paranaense U20', 219875),
('Baiano U20', 1073) : ('Baiano U20', 213790),
('Catarinense U20', 1076) : ('Catarinense U20', 215782),
('Copa Rio U20', 1082) : ('Copa Rio U20', 216059),
('Paulista - U20', 1086) : ('Paulista U20', 210903),
('Pernambucano - U20', 1088) : ('Pernambucano U20', 210906),
('Matogrossense 2', 1096) : ('Mato-Grossense', 200573),
('Copa Espírito Santo', 1097) : ('Copa Espirito Santo', 219877),
('Paulista Série B', 1098) : ('Paulista Serie B', 236839),
('Brasiliense U20', 1100) : ('Brasiliense U20', 214172),
('Carioca C', 1106) : ('Carioca C', 214754),
('Mineiro U20', 1107) : ('Mineiro U20', 213318),
('Sergipano U20', 1108) : ('Sergipano U20', 214352),
('Alagoano U20', 1110) : ('Alagoano U20', 216918),
('Cearense U20', 1112) : ('Cearense U20', 221837),
('Carioca U20', 1114) : ('Carioca U20', 210272),
('Paraense B2', 1115) : ('Paraense B1', 216728),
('Paraibano U20', 1120) : ('Paraibano U20', 220106),
('Cearense - 3', 1124) : ('Cearense 3', 217644),
('Pernambucano - 2', 1125) : ('Pernambucano 2', 202984),
},
"England" : 
{
('Premier League', 39) : ('Premier League', 1980),
('Championship', 40) : ('Championship', 1977),
('EFL Trophy', 46) : ('EFL Trophy', 197559),
('FA Cup', 45) : ('FA Cup', 1979),
('FA Trophy', 47) : ('FA Trophy', 1983),
('League Cup', 48) : ('EFL Cup', 1982),
('National League', 43) : ('National League', 1978),
('League One', 41) : None,
('League Two', 42) : ('League 2', 1958),
('Community Shield', 528) : ('Community Shield', 1953),
('FA WSL', 44) : None,
('National League - Play-offs', 49) : ('National League', 1978),
('National League - North', 50) : ('National League North', 1951),
('National League - South', 51) : ('National League South', 1952),
('Non League Div One - Isthmian North', 52) : ('Non League Division One', 228141),
('Non League Div One - Isthmian South Central', 53) : None,
('Non League Div One - Northern West', 54) : ('Non League Division One', 228141),
('Non League Div One - Northern Midlands', 55) : None,
('Non League Div One - Southern South', 56) : None,
('Non League Div One - Isthmian South East', 57) : None,
('Non League Premier - Isthmian', 58) : ('Non League Premier', 206992),
('Non League Premier - Northern', 59) : ('Non League Premier', 206992),
('Non League Premier - Southern South', 60) : ('Non League Premier', 206992),
("FA Women's Cup", 698) : ('FA Cup Women', 1981),
('Community Shield Women', 670) : ('FA Community Shield Women', 209836),
('U18 Premier League - North', 695) : ('Premier League', 1980),
('U18 Premier League - South', 696) : ('Premier League', 1980),
('WSL Cup', 697) : None,
("Women's Championship", 699) : ('Championship', 1977),
('Premier League 2 Division One', 702) : ('Northern Premier League Division 1', 201373),
('Professional Development League', 703) : ('Professional Development League U21', 198316),
('Premier League Cup', 871) : ('Premier League Cup U21', 200047),
('National League - North - Play-offs', 984) : ('National League North', 1951),
('National League - South - Play-offs', 985) : ('National League South', 1952),
('Non League Div One - Play-offs', 986) : None,
('U18 Premier League - Championship', 987) : ('Premier League Corners', 5487),
('Non League Premier - Isthmian - Play-offs', 993) : None,
('Non League Premier - Northern - Play-offs', 994) : None,
('Non League Premier - Southern South - Play-offs', 995) : None,
('Non League Premier - Southern Central - Play-offs', 996) : None,
('Non League Premier - Southern Central', 931) : None,
('Non League Div One - Northern East', 932) : ('Non League Division One', 228141),
('Non League Div One - Southern Central', 933) : None,
('FA Youth Cup', 1068) : None,
('Premier League - Summer Series', 1022) : ('Premier League Corners', 5487),
},
"Germany" : 
{
('Bundesliga', 78) : ('Bundesliga', 1842),
('2. Bundesliga', 79) : ('Bundesliga 2', 1843),
('3. Liga', 80) : ('Bundesliga 3', 1844),
('Super Cup', 529) : ('Super Cup', 2054),
('DFB Pokal', 81) : ('Cup', 2067),
('Frauen Bundesliga', 82) : None,
('U19 Bundesliga', 488) : ('Bundesliga U19', 8705),
('Regionalliga - Bayern', 83) : ('Regionalliga Bavaria', 6546),
('Regionalliga - Nord', 84) : ('Regionalliga North', 2048),
('Regionalliga - Nordost', 85) : ('Regionalliga North', 2048),
('Regionalliga - SudWest', 86) : ('Regionalliga West', 2050),
('Regionalliga - West', 87) : ('Regionalliga West', 2050),
('Oberliga - Bremen', 749) : ('Oberliga Bremen', 191452),
('Oberliga - Hessen', 750) : ('Oberliga Hessen', 191447),
('Oberliga - Niederrhein', 751) : ('Oberliga Niederrhein', 197470),
('Oberliga - Rheinland-Pfalz / Saar', 752) : ('Oberliga Rheinland-Pfalz/Saar', 191450),
('Oberliga - Baden-Württemberg', 753) : ('Oberliga Baden-Wurttemberg', 2073),
('Oberliga - Nordost-Nord', 754) : ('Oberliga Nordost Nord', 191448),
('Oberliga - Nordost-Süd', 755) : ('Oberliga Nordost Sud', 191449),
('DFB Junioren Pokal', 715) : None,
('Oberliga - Schleswig-Holstein', 744) : ('Oberliga Schleswig-Holstein', 191451),
('Oberliga - Hamburg', 745) : ('Oberliga Hamburg', 191453),
('Oberliga - Mittelrhein', 746) : ('Oberliga Mitterlrhein', 197785),
('Oberliga - Westfalen', 747) : ('Oberliga Westfalen', 197471),
('Oberliga - Niedersachsen', 748) : ('Oberliga Niedersachsen', 191454),
('DFB Pokal - Women', 947) : ('DFB Pokal Women', 2068),
('Oberliga - Promotion Round', 988) : None,
('Oberliga - Relegation Round', 989) : None,
('Regionalliga - Promotion Play-offs', 1002) : ('Regionalliga Playoff', 196875),
('Regionalliga - Relegation Round', 1003) : None,
('Oberliga - Bayern Nord', 938) : ('Oberliga Bayern Nord', 2065),
('Oberliga - Bayern Süd', 939) : ('Oberliga Bayern Sud', 2066),
('2. Frauen Bundesliga', 1034) : ('Bundesliga', 1842),
},
"Italy" : 
{
('Serie A', 135) : ('Serie A', 2436),
('Super Cup', 547) : ('Super Cup', 2153),
('Serie B', 136) : ('Serie B', 2438),
('Coppa Italia', 137) : ('Cup', 2147),
('Serie C - Girone A', 138) : ('Serie C Group A', 217401),
('Serie A Women', 139) : ('Serie A Women', 203351),
('Serie C - Girone B', 942) : ('Serie C Group B', 217400),
('Serie C - Girone C', 943) : ('Serie C Group C', 217399),
('Serie D - Girone A', 426) : ('Serie D Group A', 212572),
('Serie D - Girone B', 427) : ('Serie D Group E', 212576),
('Serie D - Girone C', 428) : ('Serie D Group E', 212576),
('Serie D - Girone D', 429) : ('Serie D Group E', 212576),
('Serie D - Girone E', 430) : ('Serie D Group E', 212576),
('Serie D - Girone F', 431) : ('Serie D Group E', 212576),
('Serie D - Girone G', 432) : ('Serie D Group E', 212576),
('Serie D - Girone H', 433) : ('Serie D Group E', 212576),
('Serie D - Girone I', 434) : ('Serie D Group E', 212576),
('Super Cup Primavera', 817) : None,
('Coppa Italia Primavera', 704) : None,
('Campionato Primavera - 1', 705) : None,
('Campionato Primavera - 2', 706) : None,
('Coppa Italia Serie C', 891) : None,
('Coppa Italia Serie D', 892) : None,
('Serie C - Relegation - Play-offs', 975) : ('Serie C', 199868),
('Serie C - Promotion - Play-offs', 976) : ('Serie C', 199868),
('Serie C - Supercoppa Lega Finals', 974) : ('Serie C', 199868),
('Serie D - Promotion - Play-offs', 997) : ('Serie D', 200813),
('Serie D - Relegation - Play-offs', 998) : ('Serie D', 200813),
('Serie D - Championship Round', 999) : ('Serie D', 200813),
},
"Netherlands" : 
{
('Eredivisie', 88) : ('Eredivisie', 1928),
('Super Cup', 543) : ('Super Cup', 1933),
('Eerste Divisie', 89) : ('Eerste Divisie', 1929),
('KNVB Beker', 90) : None,
('Eredivisie Women', 91) : ('Eredivisie Women', 192784),
('Tweede Divisie', 492) : ('Tweede Divisie', 202454),
('Derde Divisie - Saturday', 92) : ('Derde Divisie', 218533),
('Derde Divisie - Sunday', 93) : ('Derde Divisie', 218533),
('U21 Divisie 1', 675) : ('U21 Divisie', 209885),
('U18 Divisie 1', 724) : ('U21 Divisie', 209885),
('Reserve League', 883) : ('Reserve League', 194765),
('Derde Divisie - Relegation Round', 1004) : ('Derde Divisie', 218533),
},
"Portugal" : 
{
('Primeira Liga', 94) : ('Primeira Liga', 2386),
('Super Cup', 550) : ('Super Cup', 2381),
('Taça de Portugal', 96) : ('Cup', 2384),
('Segunda Liga', 95) : ('Liga 2', 2387),
('Campeonato de Portugal Prio - Group A', 457) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group B', 458) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group C', 459) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group D', 460) : ('Campeonato de Portugal Prio', 202558),
('Taça da Liga', 97) : ('League Cup', 4997),
('Taça Revelação U23', 840) : ('U23 Cup', 204968),
('Campeonato de Portugal Prio - Group E', 681) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group F', 682) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group G', 683) : ('Campeonato de Portugal Prio', 202558),
('Campeonato de Portugal Prio - Group H', 684) : ('Campeonato de Portugal Prio', 202558),
('Liga Revelação U23', 701) : ('U23 Championship', 202276),
('Liga 3', 865) : ('Liga 3', 215023),
('1a Divisão - Women', 948) : ('1st Division Women', 196966),
('Campeonato de Portugal Prio - Promotion Round', 991) : ('Campeonato de Portugal Prio', 202558),
('Júniores U19', 1041) : ('U19 Championship', 192537),
},
"Spain" : 
{
('La Liga', 140) : ('La Liga', 2196),
('Super Cup', 556) : ('Super Cup', 2463),
('Segunda División', 141) : ('Segunda Division', 2432),
('Primera División Femenina', 142) : ('Primera Division Women', 2468),
('Copa del Rey', 143) : ('Copa del Rey', 2462),
('Primera División RFEF - Group 1', 435) : ('Primera RFEF Group 1', 215328),
('Primera División RFEF - Group 2', 436) : ('Primera RFEF Group 2', 218702),
('Primera División RFEF - Group 3', 437) : ('Primera RFEF', 220076),
('Primera División RFEF - Group 4', 438) : ('Primera RFEF', 220076),
('Tercera División RFEF - Group 1', 439) : ('Tercera Division Group 1', 204809),
('Tercera División RFEF - Group 2', 440) : ('Tercera Division Group 2', 204810),
('Tercera División RFEF - Group 3', 441) : ('Tercera Division Group 3', 204811),
('Tercera División RFEF - Group 4', 442) : ('Tercera Division Group 4', 204812),
('Tercera División RFEF - Group 5', 443) : ('Tercera Division Group 5', 204813),
('Tercera División RFEF - Group 6', 444) : ('Tercera Division Group 6', 204814),
('Tercera División RFEF - Group 7', 445) : ('Tercera Division Group 7', 204815),
('Tercera División RFEF - Group 8', 446) : ('Tercera Division Group 8', 204816),
('Tercera División RFEF - Group 9', 447) : ('Tercera Division Group 9', 204817),
('Tercera División RFEF - Group 10', 448) : ('Tercera Division Group 10', 204818),
('Tercera División RFEF - Group 11', 449) : ('Tercera Division Group 11', 204819),
('Tercera División RFEF - Group 12', 450) : ('Tercera Division Group 12', 204820),
('Tercera División RFEF - Group 13', 451) : ('Tercera Division Group 13', 204821),
('Tercera División RFEF - Group 14', 452) : ('Tercera Division Group 14', 204822),
('Tercera División RFEF - Group 15', 453) : ('Tercera Division Group 15', 204823),
('Tercera División RFEF - Group 16', 454) : ('Tercera Division Group 16', 204824),
('Tercera División RFEF - Group 17', 455) : ('Tercera Division Group 17', 204825),
('Tercera División RFEF - Group 18', 456) : ('Tercera Division Group 18', 204826),
('Primera División RFEF - Group 5', 692) : ('Primera RFEF', 220076),
('Copa Federacion', 735) : ('Federation Cup', 192507),
('Segunda División RFEF - Group 1', 875) : ('Segunda División RFEF', 215547),
('Segunda División RFEF - Group 2', 876) : ('Segunda División RFEF', 215547),
('Segunda División RFEF - Group 3', 877) : ('Segunda División RFEF', 215547),
('Segunda División RFEF - Group 4', 878) : ('Segunda División RFEF', 215547),
('Segunda División RFEF - Group 5', 879) : ('Segunda División RFEF', 215547),
('Tercera División RFEF - Promotion - Play-offs', 977) : None,
('Segunda División RFEF - Play-offs', 1000) : ('Segunda RFEF Playoffs', 2429),
('Primera División RFEF - Play Offs', 1006) : None,
('Supercopa Femenina', 1058) : ('Super Cup Women', 218265),
},
"Scotland" : 
{
('Premiership', 179) : ('Premiership', 2421),
('Championship', 180) : ('Championship', 2417),
('League One', 183) : ('League One', 2418),
('League Two', 184) : ('League Two', 2419),
('League Cup', 185) : ('League Cup', 4998),
('FA Cup', 181) : ('Cup', 2426),
('Challenge Cup', 182) : ('Challenge Cup', 2420),
('Football League - Highland League', 730) :  ('Football League', 202207),
('Football League - Lowland League', 731) :  ('Football League', 202207),
('Football League - Championship', 992) : ('Football League', 202207),
('SWPL Cup', 1074) : None,
('SWF Scottish Cup', 1078) : None,
},
"Albania" : 
{
('1st Division', 311) : ('1st Division', 212294),
('Superliga', 310) : ('Superliga', 1722),
('2nd Division - Group A', 512) : ('2nd Division', 212560),
('2nd Division - Group B', 513) : ('2nd Division', 212560),
('Cup', 707) : ('Cup', 209203),
('Super Cup', 708) : ('Super Cup', 223552),
('2nd Division - Play-offs', 978) : ('2nd Division', 212560),
},
"Algeria" : 
{
('Ligue 1', 186) : ('Ligue 1', 8667),
('Ligue 2', 187) : ('Ligue 2', 200835),
('Coupe Nationale', 514) : ('Cup', 1725),
('Super Cup', 516) : None,
('U21 League 1', 515) : ('League 1 U21', 218035),
('Coupe de la Ligue', 832) : None,
},
"Palestine" : 
{
('West Bank Premier League', 586) : ('West Bank League', 10270),
},
"Myanmar" : 
{
('National League', 588) : ('National League', 210126),
},
"Trinidad-And-Tobago" : None,
"Ukraine" : 
{
('Cup', 335) : ('Cup', 2647),
('Druha Liga', 336) : ('Druha Liga', 212591),
('Persha Liga', 334) : ('Persha Liga', 201145),
('Premier League', 333) : ('Premier League', 2650),
('Druha Liga - Group B', 337) : ('Druha Liga', 212591),
('Super Cup', 678) : ('Super Cup', 215933),
('U21 League', 679) : None,
('U19 League', 1065) : ('U19 League', 125456),
},
"United-Arab-Emirates" : None,
"Uruguay" : 
{
('Segunda División', 269) : ('Segunda Division', 205369),
('Primera División - Apertura', 268) : ('Primera Division', 5593),
('Primera División - Clausura', 270) : ('Primera Division', 5593),
('Super Copa', 842) : ('Super Cup', 218468),
('Copa Uruguay', 930) : None,
},
"Tunisia" : 
{
('Ligue 1', 202) : ('League 1', 10355),
('Cup', 511) : ('Cup', 2572),
('Ligue 2', 828) : ('League 2', 201236),
},
"Turkey" : 
{
('Süper Lig', 203) : ('Super Lig U19', 228207),
('1. Lig', 204) : ('1st League', 2578),
('2. Lig', 205) : ('2nd League', 208269),
('Cup', 206) : ('Cup', 2586),
('3. Lig - Group 1', 552) : ('3rd League Group 1', 217332),
('3. Lig - Group 2', 553) : ('3rd League Group 2', 210164),
('3. Lig - Group 3', 554) : ('3rd League Group 3', 217333),
('Super Cup', 551) : ('Super Cup', 2597),
('3. Lig - Play-offs', 1007) : ('3rd League', 235357),
('3. Lig - Group 4', 1027) : ('3rd League Group 4', 227694),
},
"Egypt" : 
{
('Premier League', 233) : ('Premier League', 9885),
('Super Cup', 539) : ('Super Cup', 198532),
('Cup', 714) : ('Cup', 1946),
('Second League', 887) : None,
('Second League - Group B', 888) : None,
('Second League - Group C', 889) : None,
('League Cup', 895) : ('League Cup', 218174),
('Second League - Play-offs', 1014) : None,
},
"El-Salvador" : None,
"Estonia" : 
{
('Esiliiga A', 328) : ('Esiliiga A', 201775),
('Meistriliiga', 329) : ('Meistriliiga', 1989),
('Cup', 657) : ('Cup', 125461),
('Esiliiga B', 1126) : ('Esiliiga B', 201776),
},
"Georgia" : 
{
('Erovnuli Liga 2', 326) : ('Erovnuli Liga 2', 201857),
('Erovnuli Liga', 327) : ('Erovnuli Liga', 10236),
('Super Cup', 530) : ('Super Cup', 212164),
('David Kipiani Cup', 672) : ('FA Cup', 213517),
('Liga 3', 1104) : ('Liga 3', 207288),
},
"Ghana" : 
{
('Premier League', 570) : ('Premier League', 196927),
('Cup', 966) : ('FA Cup', 213517),
},
"Guadeloupe" : None,
"Guatemala" : 
{
('Liga Nacional', 339) : ('Liga Nacional', 2088),
('Primera Division', 338) : ('Primera Division de Ascenso', 202739),
},
"Greece" : 
{
('Cup', 199) : ('Cup', 2080),
('Football League', 198) : ('Football League', 10250),
('Super League 1', 197) : ('Super League', 2081),
('Super League 2', 494) : ('Super League 2', 206711),
('Gamma Ethniki - Group 1', 576) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 2', 577) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 3', 578) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 4', 579) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 5', 580) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 6', 581) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 7', 582) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 8', 583) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 9', 693) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Group 10', 694) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Promotion Group', 990) : ('Gamma Ethniki', 217489),
('Gamma Ethniki - Relegation Play-offs', 1099) : ('Gamma Ethniki', 217489),
},
"Andorra" : 
{
('1a Divisió', 312) : ('Premier Division', 211232),
('2a Divisió', 313) : None,
('Copa Constitució', 655) : ('Cup', 233882),
('Super Cup', 809) : None,
},
"Argentina" : 
{
('Primera B Metropolitana', 131) : ('Primera B Metropolitana', 201149),
('Primera Nacional', 129) : ('Primera B Nacional', 1739),
('Primera C', 132) : None,
('Primera D', 133) : None,
('Torneo Federal A', 134) : ('Torneo Federal A', 202608),
('Liga Profesional Argentina', 128) : None,
('Copa Argentina', 130) : ('Cup', 1741),
('Trofeo de Campeones de la Superliga', 517) : ('Trofeo des Campeones', 223046),
('Super Copa', 810) : ('Super Cup', 192769),
('Copa de la Superliga', 483) : None,
('Reserve League', 906) : ('Reserve League', 200786),
('Copa de la Liga Profesional', 1032) : ('Copa de la Liga Profesional', 204784),
('Torneo Promocional Amateur', 1067) : ('Torneo Promocional Amateur', 234301),
},
"Australia" : 
{
('A-League', 188) : ('A League', 1766),
('Brisbane Premier League', 191) : ('Brisbane Premier League', 1749),
('Northern Territory Premier League', 193) : ('NorZone Premier League', 209510),
('Northern NSW NPL', 481) : ('NPL Northern NSW', 8594),
('Capital Territory NPL', 189) : ('NPL Capital Territory', 8592),
('A-League Women', 190) : ('A-League Women', 10030),
('New South Wales NPL', 192) : ('NPL New South Wales', 8588),
('South Australia NPL', 194) : ('NPL South Australia', 1753),
('Victoria NPL', 195) : ('NPL Victoria', 1769),
('Western Australia NPL', 196) : ('Western Australia Cup', 9318),
('Queensland NPL', 482) : ('NPL Queensland', 8584),
('Tasmania NPL', 648) : ('NPL Tasmania', 163720),
('Queensland Premier League', 833) : ('Queensland Premier League', 213666),
('South Australia State League 1', 834) : ('South Australia State League 1', 194630),
('New South Wales NPL 2', 835) : ('New South Wales League 2', 212331),
('Victoria NPL 2', 836) : None,
('Australia Cup', 874) : ('Western Australia Cup', 9318),
('NNSW League 1', 1090) : None,
('Tasmania Northern Championship', 1091) : ('Tasmania Northern Championship', 214014),
('Capital Territory NPL 2', 1092) : ('NPL Capital Territory', 8592),
('Tasmania Southern Championship', 1093) : ('Tasmania Southern Championship', 204673),
('Western Australia State League 1', 1094) : ('Western Australia State League 1', 219117),
},
"Austria" : 
{
('Cup', 220) : ('Cup', 1776),
('2. Liga', 219) : ('2. Liga', 1773),
('Bundesliga', 218) : ('Bundesliga', 1792),
('Regionalliga - Mitte', 222) : ('Regionalliga Mitte', 1785),
('Regionalliga - Ost', 221) : ('Regionalliga Ost', 1784),
('Regionalliga - West', 223) : ('Regionalliga West', 1786),
('Landesliga - Burgenland', 224) : ('Landesliga', 201501),
('Landesliga - Karnten', 225) : ('Landesliga', 201501),
('Landesliga - Niederosterreich', 226) : ('Landesliga', 201501),
('Landesliga - Oberosterreich', 227) : ('Landesliga', 201501),
('Landesliga - Salzburg', 228) : ('Landesliga', 201501),
('Landesliga - Steiermark', 229) : ('Landesliga', 201501),
('Landesliga - Tirol', 230) : ('Landesliga', 201501),
('Landesliga - Vorarlbergliga', 231) : ('Landesliga', 201501),
('Landesliga - Wien', 232) : ('Landesliga', 201501),
('Frauenliga', 484) : None,
('Regionalliga - Tirol', 687) : ('Regionalliga Tirol', 206303),
('Regionalliga - Salzburg', 688) : ('Regionalliga Salzburg', 206230),
},
"Azerbaidjan" : None,
"Wales" : 
{
('Premier League', 110) : ('Premier League', 2678),
('Welsh Cup', 112) : ('Cup', 2679),
('FAW Championship', 111) : ('Championship', 214556),
('League Cup', 738) : ('League Cup', 10285),
},
"Venezuela" : 
{
('Primera División', 299) : ('Primera Division', 5596),
('Segunda División', 300) : ('Segunda Division', 201212),
('Copa Venezuela', 1113) : ('Cup', 5597),
},
"Oman" : 
{
('Professional League', 406) : ('Pro League', 210715),
('Sultan Cup', 726) : ('Cup', 2352),
('Super Cup', 944) : ('Super Cup', 233460),
},
"Jamaica" : 
{
('Premier League', 322) : ('Premier League', 10407),
},
"Jordan" : 
{
('League', 387) : ('Pro League', 9902),
('Shield Cup', 816) : ('Shield Cup', 2169),
('Super Cup', 838) : ('Super Cup', 191461),
('Cup', 863) : ('Cup', 2167),
},
"Kazakhstan" : 
{
('1. Division', 388) : ('Premier League', 6418),
('Premier League', 389) : ('Premier League', 6418),
('Cup', 498) : ('Cup', 2176),
('Super Cup', 818) : ('Super Cup', 10967),
},
"Kuwait" : 
{
('Premier League', 330) : ('Premier League', 10380),
('Division 1', 331) : ('Division 1', 212200),
('Crown Prince Cup', 820) : ('Crown Prince Cup', 200547),
('Super Cup', 719) : ('Super Cup', 191669),
('Emir Cup', 720) : ('Emir Cup', 194698),
},
"Denmark" : 
{
('Superliga', 119) : ('Superliga', 1913),
('1. Division', 120) : ('Division 1', 1904),
('Denmark Series - Group 1', 124) : ('Denmark Series', 201505),
('Denmark Series - Group 2', 125) : ('Denmark Series', 201505),
('Denmark Series - Group 3', 126) : ('Denmark Series', 201505),
('DBU Pokalen', 121) : ('Cup', 1908),
('2nd Division - Group 1', 122) : ('2nd Division', 191393),
('2nd Division - Group 2', 123) : ('2nd Division', 191393),
('Denmark Series - Group 4', 127) : ('Denmark Series', 201505),
('Kvindeliga', 638) : None,
('3. Division', 862) : ('3rd Division', 214819),
('Denmark Series - Promotion Round', 982) : ('Denmark Series', 201505),
('Denmark Series - Relegation Round', 983) : ('Denmark Series', 201505),
},
"Honduras" : 
{
('Liga Nacional', 234) : ('Liga Nacional', 196865),
},
"Hong-Kong" : None,
"Hungary" : 
{
('Magyar Kupa', 273) : ('Cup', 2096),
('NB I', 271) : ('NB 1', 2095),
('NB II', 272) : ('NB 2', 201214),
('NB III - Northeast', 633) : ('NB 3 East', 224382),
('NB III - Southwest', 634) : ('NB 3 West', 224384),
('NB III - Northwest', 635) : ('NB 3 West', 224384),
('NB III - Promotion Play-offs', 1111) : ('NB 3', 208665),
('NB III - Southeast', 1023) : ('NB 3 East', 224382),
},
"Lebanon" : 
{
('Premier League', 390) : ('Premier League', 2205),
('Cup', 967) : ('Super Cup', 227023),
('Federation Cup', 1018) : None,
},
"Luxembourg" : 
{
('National Division', 261) : ('National Division', 2228),
('Cup', 721) : ('Cup', 196904),
},
"Qatar" : 
{
('Second Division', 306) : ('2nd Division', 202606),
('Stars League', 305) : ('Stars League', 8128),
('QSL Cup', 677) : ('Cup', 10905),
('QFA Cup', 841) : ('QFA Cup', 212958),
('Emir Cup', 824) : ('Emir Cup', 10903),
('Qatar Cup', 825) : ('Stars Cup', 10901),
},
"Surinam" : None,
"Tajikistan" : 
{
('Vysshaya Liga', 571) : ('Higher League', 208861),
},
"Barbados" : 
{
('Premier League', 422) : ('Premier League', 201863),
},
"Uganda" : 
{
('Premier League', 585) : ('Premier League', 211166),
},
"Mali" : 
{
('Première Division', 598) : ('Premiere Division', 218137),
},
"USA" : 
{
('Major League Soccer', 253) : ('Major League Soccer', 2663),
('US Open Cup', 257) : ('Open Cup', 2662),
('USL Championship', 255) : ('USL Championship', 201065),
('USL League Two', 256) : ('USL League 2', 201642),
('USL League One', 489) : ('USL League One', 205322),
('NISA', 523) : ('NISA', 206791),
('NWSL Women', 254) : ('National Womens Soccer League', 201290),
('NWSL Women - Challenge Cup', 641) : ('NWSL Cup', 209296),
('MLS All-Star', 866) : None,
('MLS Next Pro', 909) : ('MLS Next Pro League', 219120),
('USL League One Cup', 1095) : ('USL League One', 205322),
('WPSL', 1116) : ('Women Premier Soccer League', 201730),
('USL W League', 1117) : ('USL W League', 219811),
('NPSL', 1118) : ('NPSL', 201813),
('NWSL - Liga MXF Summer Cup', 1119) : None,
},
"Uzbekistan" : 
{
('Super League', 369) : ('Super League', 202026),
('Cup', 802) : ('Cup', 131783),
('Super Cup', 830) : ('Super Cup', 212333),
('Pro League A', 1075) : ('Pro League', 210207),
},
"Thailand" : 
{
('Thai League 1', 296) : ('League 1', 6419),
('Thai League 2', 297) : ('League 2', 200748),
('FA Cup', 298) : ('FA Cup', 6420),
('Thai Champions Cup', 873) : ('Champions Cup', 221321),
('League Cup', 898) : ('League Cup', 9096),
},
"Faroe-Islands" : None,
"Finland" : 
{
('Ykkönen', 245) : ('Ykkonen', 234884),
('Veikkausliiga', 244) : ('Veikkausliiga', 2024),
('Suomen Cup', 246) : None,
('Kakkonen - Lohko A', 247) : ('Kakkonen', 2018),
('Kakkonen - Lohko B', 248) : ('Kakkonen', 2018),
('Kakkonen - Lohko C', 249) : ('Kakkonen', 2018),
('Kansallinen Liiga', 640) : None,
('Kakkosen Cup', 700) : ('Kakkosen Cup', 203922),
('League Cup', 899) : ('League Cup', 4993),
('Ykköscup', 901) : ('Ykkoscup', 218491),
('Kakkonen - Play-offs', 1052) : ('Kakkosen Cup', 203922),
('Ykkösliiga', 1087) : ('Ykkosliiga', 2025),
},
"Ecuador" : 
{
('Liga Pro', 242) : ('Serie A', 5598),
('Liga Pro Serie B', 243) : ('Serie B', 197248),
('Supercopa de Ecuador', 853) : ('Supercopa', 207919),
('Copa Ecuador', 917) : ('Cup', 219609),
},
"Angola" : 
{
('Girabola', 397) : ('Girabola', 208764),
},
"Armenia" : 
{
('First League', 343) : ('1st League', 201171),
('Premier League', 342) : ('Premier League', 1742),
('Super Cup', 654) : ('Super Cup', 209579),
('Cup', 709) : ('Cup', 191700),
},
"Belarus" : 
{
('Premier League', 116) : ('Premier League', 6416),
('1. Division', 117) : ('1st Division', 201855),
('2. Division', 118) : ('2nd Division', 209061),
('Coppa', 486) : ('Cup', 1813),
('Reserve League', 562) : ('Reserve League', 208749),
('Super Cup', 812) : ('Super Cup', 204392),
},
"Zambia" : 
{
('Super League', 400) : ('Super League', 211601),
},
"Vietnam" : 
{
('V.League 1', 340) : ('V League', 9154),
('Cup', 341) : ('Cup', 9253),
('V.League 2', 637) : ('V League 2', 201256),
('Super Cup', 831) : ('Super Cup', 211452),
},
"Japan" : 
{
('Emperor Cup', 102) : ('Cup', 2160),
('J-League Cup', 101) : ('League Cup', 4995),
('J1 League', 98) : ('J League', 2157),
('J2 League', 99) : ('J2 League', 2159),
('J3 League', 100) : ('J3 League', 10078),
('Japan Football League', 497) : ('Football League', 201838),
('Super Cup', 548) : ('Super Cup', 5421),
('WE League', 854) : ('Women Empowerment League', 215919),
},
"Kenya" : 
{
('FKF Premier League', 276) : ('Premier League', 187707),
('Super League', 277) : ('Super League', 201475),
('Shield Cup', 971) : ('Shield Cup', 199972),
},
"Haiti" : 
{
('Ligue Haïtienne', 379) : ('Division 1', 208754),
},
"Latvia" : 
{
('1. Liga', 364) : ('1st Liga', 202003),
('Virsliga', 365) : ('Virsliga', 2203),
('Cup', 658) : ('Cup', 2204),
},
"Lithuania" : 
{
('1 Lyga', 361) : (' 1 Lyga', 201890),
('A Lyga', 362) : (' A Lyga', 2211),
('Cup', 661) : ('Cup', 10150),
('Super Cup', 839) : ('Super Cup', 212788),
},
"Singapore" : 
{
('League Cup', 505) : None,
('Premier League', 368) : ('Premier League', 210554),
('Cup', 959) : ('Cup', 9945),
},
"Aruba" : 
{
('Division di Honor', 421) : ('Divison di Honor', 208767),
},
"Fiji" : 
{
('National Football League', 376) : ('National Football League', 203918),
},
"Guinea" : None,
"Chile" : 
{
('Super Cup', 527) : ('Super Cup', 197657),
('Primera División', 265) : ('Primera Division', 1857),
('Primera B', 266) : ('Primera B', 10279),
('Copa Chile', 267) : ('Cup', 1856),
('Segunda División', 711) : ('Segunda Division', 201664),
},
"Czech-Republic" : None,
"Ethiopia" : 
{
('Premier League', 363) : ('Premier League', 211244),
},
"Tanzania" : 
{
('Ligi kuu Bara', 567) : ('Liga Kuu Bara', 210946),
},
"Romania" : 
{
('Supercupa', 555) : ('Super Cup', 187758),
('Liga I', 283) : ('Liga 1', 2395),
('Liga II', 284) : ('Liga 2', 199710),
('Cupa României', 285) : ('Cup', 2396),
('Liga III - Serie 1', 784) : None,
('Liga III - Serie 2', 785) : None,
('Liga III - Serie 3', 786) : None,
('Liga III - Serie 4', 787) : None,
('Liga III - Serie 5', 788) : None,
('Liga III - Serie 6', 789) : None,
('Liga III - Serie 7', 790) : None,
('Liga III - Serie 8', 791) : None,
('Liga III - Serie 9', 792) : None,
('Liga III - Serie 10', 793) : None,
('Liga 1 Feminin', 728) : ('Liga 1 Women', 217134),
('Liga III - Play-offs', 1009) : None,
},
"Sweden" : 
{
('Ettan - Norra', 563) : ('Division 1 Norra', 2510),
('Ettan - Södra', 564) : ('Division 1 Sodra', 2513),
('Allsvenskan', 113) : ('Allsvenskan', 1728),
('Superettan', 114) : ('Superettan', 2476),
('Division 2 - Norra Götaland', 592) : ('2nd Div. Norra Gotaland', 191455),
('Division 2 - Norra Svealand', 593) : ('2nd Div. Norra Svealand', 2481),
('Division 2 - Norrland', 594) : ('2nd Div. Norrland',  2487),
('Division 2 - Södra Svealand', 595) : ('2nd Div. Sodra Svealand', 2485),
('Division 2 - Västra Götaland', 596) : ('2nd Div. Vastra Gotaland', 2486),
('Division 2 - Östra Götaland', 597) : ('2nd Div. Ostra Gotaland', 2483),
('Svenska Cupen', 115) : ('Cup', 2516),
('Damallsvenskan', 549) : ('Damallsvenskan', 1903),
('Svenska Cupen - Women', 737) : ('Women Cup', 204223),
('Elitettan', 736) : ('Elitettan Women', 210423),
('Division 2 - Play-offs', 1053) : ('Division 2',  223188),
('Ettan - Relegation Round', 1055) : None,
},
"Kyrgyzstan" : 
{
('Premier League', 569) : ('Premier League', 212466),
},
"Bosnia" : None,
"South-Korea" : None,
"Iran" : 
{
('Hazfi Cup', 495) : ('Cup', 10346),
('Persian Gulf Pro League', 290) : ('Pro League', 2118),
('Azadegan League', 291) : ('Azadegan League', 209653),
('Super Cup', 905) : None,
},
"Israel" : 
{
('Liga Alef', 496) : ('Liga Alef', 10604),
('Liga Leumit', 382) : ('Ligat Leumit', 2133),
("Ligat Ha'al", 383) : ("Liga ha'Al", 212975),
('State Cup', 384) : ('State Cup', 2129),
('Toto Cup Ligat Al', 385) : ('Ligat Al Toto Cup Corners', 198186),
('Super Cup', 659) : ('Super Cup', 191425),
},
"Slovakia" : 
{
('2. liga', 506) : ('2. Liga', 201139),
('Super Liga', 332) : ('Super Liga', 2453),
('3. liga - Bratislava', 643) : ('3. Liga', 210303),
('3. liga - West', 644) : ('3. Liga', 210303),
('3. liga - East', 645) : ('3. Liga', 210303),
('3. liga - Center', 646) : ('3. Liga', 210303),
('Cup', 680) : ('Cup', 2454),
('I Liga - Women', 733) : ('Liga I Women', 202382),
},
"Macedonia" : 
{
('First League', 371) : ('1st League', 2230),
('Second League', 372) : ('2nd League', 212550),
('Cup', 756) : ('Cup', 207309),
},
"Ivory-Coast" : None,
"Malta" : 
{
('Challenge League', 392) : ('Challenge League', 210657),
('Premier League', 393) : ('Premier League', 2238),
('FA Trophy', 821) : ('FA Trophy', 2236),
('Super Cup', 1050) : ('Super Cup', 198220),
},
"Moldova" : 
{
('Super Liga', 394) : None,
('Liga 1', 395) : None,
('Cupa', 674) : ('Cup', 209278),
},
"Nicaragua" : 
{
('Primera Division', 396) : ('Primera Division', 197584),
('Liga Primera U20', 565) : ('Liga Primera U20', 208823),
},
"Nigeria" : 
{
('NPFL', 399) : ('NPFL', 199487),
},
"Zimbabwe" : None,
"Sudan" : 
{
('Sudani Premier League', 402) : ('Premier League', 214757),
},
"Senegal" : 
{
('Ligue 1', 403) : ('Ligue 1', 217859),
},
"San-Marino" : None,
"Cameroon" : 
{
('Elite One', 411) : ('Elite One', 1849),
('Elite Two', 813) : ('Elite Two', 201157),
},
"Cambodia" : 
{
('C-League', 410) : ('Premier League', 204591),
},
"Bahrain" : 
{
('Premier League', 417) : ('Premier League', 1797),
('Federation Cup', 485) : ('Federation Cup', 212497),
("King's Cup", 1049) : ('Kings Cup', 1800),
('Super Cup', 1109) : ('Super Cup', 202581),
},
"Benin" : 
{
('Championnat National', 415) : ('Ligue 1', 212495),
},
"Bermuda" : None,
"Bhutan" : 
{
('Super League', 413) : None,
('Premier League', 1031) : ('Premier League', 210712),
},
"Botswana" : 
{
('Premier League', 412) : ('Premier League', 218775),
},
"Bangladesh" : 
{
('Premier League', 398) : ('Premier League', 88184),
('Federation Cup', 811) : ('Federation Cup', 199229),
},
"Norway" : 
{
('Eliteserien', 103) : ('Eliteserien', 2333),
('1. Division', 104) : ('1st Division', 2331),
('Super Cup', 557) : ('Super Cup', 198947),
('2. Division - Group 1', 473) : ('2nd Division', 2332),
('2. Division - Group 2', 474) : ('2nd Division', 2332),
('NM Cupen', 105) : None,
('3. Division - Girone 1', 774) : ('3rd Division Group 1', 201285),
('3. Division - Girone 2', 775) : ('3rd Division Group 2', 216989),
('3. Division - Girone 3', 776) : ('3rd Division Group 3', 216990),
('3. Division - Girone 4', 777) : ('3rd Division Group 4', 216991),
('3. Division - Girone 5', 778) : ('3rd Division Group 5', 216992),
('3. Division - Girone 6', 779) : ('3rd Division Group 6', 216993),
('Toppserien', 725) : ('Toppserien Women', 196861),
('Nasjonal U19 Champions League', 823) : ('U19 League',  201238),
('1. Division Women', 915) : ('1st Division Women', 201957),
('2. Division - Play-offs', 1054) : ('2nd Division', 2332),
},
"Costa-Rica" : None,
"Iceland" : 
{
('Úrvalsdeild', 164) : None,
('1. Deild', 165) : ('1. Deild', 2100),
('2. Deild', 166) : ('2. Deild', 197293),
('Cup', 167) : ('Cup', 2101),
('League Cup', 168) : ('League Cup', 4994),
('Super Cup', 639) : ('Super Cup', 201333),
('Úrvalsdeild Women', 671) : ('Urvalsdeild Women', 197088),
('Reykjavik Cup', 814) : ('Reykjavik Cup', 192494),
('Fotbolti.net Cup A', 815) : ('Fotbolti.net Cup', 10509),
},
"China" : 
{
('Super League', 169) : ('Super League', 6417),
('League One', 170) : ('League One', 8655),
('FA Cup', 171) : ('FA Cup', 1859),
('League Two', 929) : ('League Two', 213349),
('Super Cup', 972) : ('Super Cup', 10813),
},
"Morocco" : 
{
('Botola Pro', 200) : ('Botola Pro', 2253),
('Botola 2', 201) : ('Botola 2', 207422),
('Cup', 822) : ('Cup', 10288),
},
"Switzerland" : 
{
('Super League', 207) : ('Super League', 2517),
('Challenge League', 208) : ('Challenge League', 2518),
('1. Liga Promotion', 510) : ('Promotion League',  219077),
('Schweizer Cup', 209) : ('Cup', 2519),
('1. Liga Classic - Group 1', 599) : ('1. Liga Classic', 201159),
('1. Liga Classic - Group 2', 600) : ('1. Liga Classic', 201159),
('1. Liga Classic - Group 3', 601) : ('1. Liga Classic', 201159),
('2. Liga Interregional - Group 1', 796) : None,
('2. Liga Interregional - Group 2', 797) : None,
('2. Liga Interregional - Group 3', 798) : None,
('2. Liga Interregional - Group 4', 799) : None,
('2. Liga Interregional - Group 5', 800) : None,
('2. Liga Interregional - Group 6', 801) : None,
('AXA Women’s Super League', 739) : ('Super League Women', 210756),
('1. Liga Classic - Play-offs', 1005) : ('1. Liga Classic', 201159),
('Erste Liga Cup', 1044) : ('Erste Liga Cup', 230393),
},
"Croatia" : 
{
('HNL', 210) : ('HNL', 1880),
('First NL', 211) : ('Prva NL', 1881),
('Cup', 212) : ('Cup', 1882),
('Third NL - Istok', 213) : ('3. NL', 222092),
('Third NL - Jug', 214) : ('3. NL', 222092),
('Third NL - Sjever', 215) : ('3. NL', 222092),
('Third NL - Sredite', 216) : ('3. NL', 222092),
('Third NL - Zapad', 217) : ('3. NL', 222092),
('Second NL', 946) : ('2. NL', 201210),
('Super Cup', 1021) : ('Super Cup', 205799),
},
"Russia" : None,
"Colombia" : 
{
('Primera A', 239) : ('Primera A', 5591),
('Primera B', 240) : ('Primera B', 10921),
('Copa Colombia', 241) : ('Cup', 1867),
('Liga Femenina', 712) : ('Liga Women', 201441),
('Superliga', 713) : ('Superliga', 209948),
},
"Paraguay" : 
{
('Division Profesional - Apertura', 250) : ('Division Profesional', 2359),
('Division Intermedia', 251) : ('Division Intermedia', 201859),
('Division Profesional - Clausura', 252) : ('Division Profesional', 2359),
('Copa Paraguay', 501) : ('Cup', 202152),
('Supercopa', 961) : ('Super Cup', 224028),
},
"Bulgaria" : 
{
('Second League', 173) : ('Second League', 202119),
('Cup', 174) : ('Cup', 1839),
('First League', 172) : ('First League', 9320),
('Third League - Northeast', 175) : ('Third League', 209887),
('Third League - Northwest', 176) : ('Third League', 209887),
('Third League - Southeast', 177) : ('Third League', 209887),
('Third League - Southwest', 178) : ('Third League', 209887),
('Super Cup', 656) : ('Super Cup', 9503),
},
"Mexico" : 
{
('Liga MX', 262) : None,
('Liga de Expansión MX', 263) : ('Liga de Expansión MX', 209758),
('Copa MX', 264) : ('Cup', 5778),
('Copa por México', 662) : None,
('Liga MX Femenil', 673) : ('Liga MX Women', 201165),
('Liga Premier Serie A', 722) : ('Liga Premier', 207004),
('Campeón de Campeones', 857) : ('Champion of Champions',  205749),
('U20 League', 861) : ('U20 League', 10602),
('Liga Premier Serie B', 872) : ('Liga Premier Serie B', 207005),
('U23 League', 1017) : ('U23 League', 226745),
},
"Canada" : 
{
('Canadian Championship', 259) : ('Championship', 1850),
('Canadian Soccer League', 258) : ('Soccer League', 1851),
('Pacific Coast Soccer League', 260) : None,
('Canadian Premier League', 479) : ('Premier League', 205098),
('League 1 Ontario', 923) : None,
},
"Malaysia" : 
{
('Super League', 278) : ('Super League', 2234),
('Premier League', 279) : ('Premier League', 2233),
('Malaysia Cup', 499) : ('Cup', 2232),
('FA Cup', 500) : ('FA Cup', 198556),
},
"New-Zealand" : None,
"Peru" : 
{
('Primera División', 281) : ('Liga 1', 2366),
('Segunda División', 282) : ('Liga 2', 201986),
('Copa Bicentenario', 502) : ('Copa Bicentenario', 205707),
('Copa Perú', 503) : ('Copa Peru', 5592),
('Supercopa', 558) : ('Super Cup', 207704),
},
"Serbia" : 
{
('Super Liga', 286) : ('Super Liga', 2434),
('Prva Liga', 287) : ('Prva Liga', 206162),
('Srpska Liga - Belgrade', 572) : None,
('Srpska Liga - Vojvodina', 573) : None,
('Srpska Liga - East', 574) : None,
('Srpska Liga - West', 575) : None,
('Cup', 732) : ('Cup', 2435),
},
"South-Africa" : None,
"Saudi-Arabia" : None,
"Northern-Ireland" : None,
"Syria" : 
{
('Premier League', 425) : ('Premier League', 10334),
},
"Libya" : 
{
('Premier League', 584) : ('Premier', 2208),
},
"Chinese-Taipei" : None,
"Indonesia" : 
{
('Liga 1', 274) : ('Liga 1', 199211),
('Piala Indonesia', 718) : ('Menpora Cup', 212701),
('Liga 2', 275) : ('Liga 2', 201493),
('Piala Presiden', 924) : ('Presidents Cup', 191920),
},
"Panama" : 
{
('Liga Panameña de Fútbol', 304) : ('Primera Division', 10573),
},
"Poland" : 
{
('Ekstraklasa', 106) : ('Ekstraklasa', 2374),
('I Liga', 107) : ('1st Liga', 6633),
('II Liga - East', 109) : ('2nd Liga', 2368),
('Cup', 108) : ('Cup', 2373),
('III Liga - Group 1', 780) : ('3rd Liga Group 1', 201204),
('III Liga - Group 2', 781) : ('3rd Liga Group 2', 216986),
('III Liga - Group 3', 782) : ('3rd Liga Group 3', 216987),
('III Liga - Group 4', 783) : ('3rd Liga Group 4', 216988),
('Central Youth League', 676) : None,
('Super Cup', 727) : ('Super Cup', 5828),
('Ekstraliga Women', 1033) : ('Ekstraliga Women', 163787),
},
"Cyprus" : 
{
('1. Division', 318) : ('1st Division', 1887),
('2. Division', 319) : ('2nd Division', 201240),
('3. Division', 320) : ('2nd Division', 201240),
('Cup', 321) : ('Cup', 1888),
('Super Cup', 852) : ('Super Cup', 1890),
},
"India" : 
{
('Indian Super League', 323) : ('Super League', 10083),
('I-League', 324) : ('I-League', 10578),
('AIFF Super Cup', 545) : ('Super Cup', 201000),
('Santosh Trophy', 325) : ('Santosh Trophy', 204696),
('I-League - 2nd Division', 717) : ('I-League 2', 201143),
('Calcutta Premier Division', 1020) : ('Calcutta Premier Division', 202235),
},
"Montenegro" : 
{
('First League', 355) : ('Prva Liga', 206165),
('Second League', 356) : ('Druga Liga', 209191),
('Cup', 723) : ('Cup', 219391),
},
"Bolivia" : 
{
('Primera División', 344) : ('Primera Division', 5595),
('Nacional B', 710) : None,
('Copa de la División Profesional', 964) : ('Copa Division Profesional', 224467),
},
"Slovenia" : 
{
('1. SNL', 373) : ('3. SNL', 213328),
('2. SNL', 374) : ('2. SNL', 201109),
('Cup', 375) : ('Cup', 2456),
('3. SNL - East', 794) : None,
('3. SNL - West', 795) : None,
},
"Malawi" : 
{
('Super League', 391) : ('Super League', 211386),
},
"Rwanda" : 
{
('National Soccer League', 405) : ('Premier League', 211116),
},
"Namibia" : None,
"Belize" : None,
"Burkina-Faso" : None,
"Congo-DR" : None,
"Ireland" : 
{
("FAI President's Cup", 546) : None,
('FAI Cup', 359) : ('FAI Cup', 2124),
('League Cup', 360) : ('League Cup', 216406),
('Premier Division', 357) : ('Premiership Women', 201640),
('First Division', 358) : ('Division 1', 2123),
},
"Burundi" : 
{
('Ligue A', 566) : ('Premier League', 208777),
},
"Curacao" : None,
"Kosovo" : None,
"Nepal" : 
{
('A Division', 590) : ('A Division', 217495),
},
"Turkmenistan" : 
{
('Ýokary Liga', 636) : ('Higher League', 208912),
('Youth League', 829) : None,
},
"Gibraltar" : 
{
('Premier Division', 758) : ('Football League', 10748),
('Rock Cup', 837) : ('Rock Cup', 218535),
('Super Cup', 1042) : ('Super Cup', 200801),
},
"Dominican-Republic" : None,
"Liberia" : None,
"Liechtenstein" : 
{
('Cup', 761) : ('Cup', 219535),
},
"Mauritania" : 
{
('Premier League', 762) : ('Ligue 1', 218013),
},
"Mauritius" : None,
"Mongolia" : 
{
('Premier League', 764) : None,
},
"Philippines" : 
{
('PFL', 765) : ('PFL', 10745),
('Copa Paulino Alcantara', 867) : ('Copa Paulino Alcantara', 202605),
},
"Congo" : None,
"Gambia" : 
{
('GFA League', 845) : ('GFA League', 212509),
},
"Eswatini" : None,
"Iraq" : 
{
('Iraqi League', 542) : ('Premier League', 125378)
},
"Laos" : 
{
('Lao League', 647) : ('League 1', 225136),
},
"Somalia" : None,
"Maldives" : 
{
('Dhivehi Premier League', 855) : ('Premier League', 218649),
},
"Pakistan" : 
{
('Premier League', 868) : ('Premier League', 215339),
},
"Crimea" : None,
"Lesotho" : None,
"Gabon" : None,
"Cuba" : None,
"Antigua-And-Barbuda" : None,
"Yemen" : None,
"Grenada" : None,
"Togo" : 
{
('Championnat National', 1084) : ('Championnat National', 218786),
},
"Macao" : 
{
('Primeira Divisão', 969) : ('Primeira Divisao', 201899),
},
}